@@ -37,6 +37,12 @@ class InvaildHostError(InstaClientError):
     Args:
         host_int:int: The driver int variable passed to InstaClient()
     """
+    def __init__(self, host_int:int):
+        self.host_int = host_int
+        super().__init__(message='This integer does not refer to any host type')
+
+    def __str__(self):
+        return f'{self.host_int} -> {self.message}'
     
 
 
@@ -54,6 +60,13 @@ class InvaildDriverError(InstaClientError):
         return f'{self.driver_int} -> {self.message}'
 
 
+class InvalidErrorCallbackError(InstaClientError):
+    """Raised when initiating an InstaClient object if the `error_callback` argument is provided but is not a callable object.
+    """
+    def __init__(self):
+        super().__init__(message='The error callback you provided is not a callable.')
+
+
 class InvalidUserError(InstaClientError):
     """Raised when searching for an incorrect user's username or when trying to login with an unexisting account's username
     
